==> hoteldruid-mod-nl_2.2.1-1.zip: nl/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":  				$messaggio = "File gemaakt"; break;
case "Si è verificato un errore cancellando il file":	$messaggio = "Er is een fout opgetreden met het wissen van de file"; break;
case "File cancellato":  			$messaggio = "File gewist"; break;
case "Inserisci i nuovi dati per la connessione al database":	$messaggio = "Voeg nieuwe data in voor verbinding met database"; break;
case "Nome del database da utilizzare":		$messaggio = "Te gebruiken database naam"; break;
case "Database già esistente":  		$messaggio = "Bestaande ddatabase"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nee"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Indien reeds bestaand en niet leeg gebruik dan een prefix die niet in de database voor tabelnamen wordt gebruikt"; break;
case "Nome del computer a cui collegarsi":	$messaggio = "Naam van de computer waarmee verbonden moet worden"; break;
case "Numero della porta a cui collegarsi":	$messaggio = "Poortnaam waarmee verbonden moet worden"; break;
case "Nome per l'autenticazione al database":	$messaggio = "Gebruikersnaam voor databse verificatie"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Password voor database verificatie"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Laad de dynamische librarie \"pgsql.so\" of \"mysql.so\""; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "kies ja als er niet automatisch wordt geladen door PHP"; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Naam van de database waarmee tijdelijk wordt verbonden"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "allen voor Postgresql met niet bestaande database"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":	$messaggio = "Oude databse leeg gemaakt, en kan niet geheel worden verwijderd"; break;
case "Database creato":  			$messaggio = "Database gemaakt"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":	$messaggio = "Het was niet mogelijk om met de nieuwe database verbinding te maken, controleer verbindings gegevens, de gebruikers rechten of de naam van de database"; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":	$messaggio = "Het was niet mogelijk een neiuwe databse te makencontroleer verbindings gegevens, de gebruikers rechten of de naam van de database of dat er een database reeds bestaat genaamd"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Ik heb geen schrijfrechten in de dati map"; break;
case "Non ho potuto leggere il file":  		$messaggio = "De file is niet leesbaar"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Crea il file di backup":  		$messaggio = "Maak een backup file"; break;
case "Crea un nuovo file di backup":  		$messaggio = "Maak een nieuwe backup file"; break;
case "sovrascrivendo l'attuale":  		$messaggio = "overschrijf de huidige"; break;
case "Guarda il file":				$messaggio = "Bekijk de file"; break;
case "Cancella":  				$messaggio = "Wis"; break;
case " l'attuale file di backup":  		$messaggio = " huidige backup file"; break;
case "Ripristina i dati dal file":  		$messaggio = "Herstel data van file"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":	$messaggio = " (huidige data owrdt gewist), gebruiken voor maken van database:"; break;
case "i dati dell'attuale connessione":  	$messaggio = "data van huidige verbinding"; break;
case "nuovi dati":  				$messaggio = "nieuwe data"; break;
case "Non ho potuto fare l'upload del file":	$messaggio = "Niet mogelijk de file te uploaden"; break;
case " del file di backup":  			$messaggio = " deze backup file"; break;
case " di un nuovo file di backup":  		$messaggio = " deze nieuwe backup file"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix in tabellen naam"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "De prefix van tabelnamen is verkeerd (accepteer alleen kleine letters, getallen en _ , als eerste letter)"; break;
case "Il contenuto del file inviato non è corretto":	$messaggio = "De inhoud van de verzedn file is verkeeerd"; break;
case "Il formato del file è errato":  		$messaggio = "Het file formaat is verkeerd"; break;
case "Compresso":  				$messaggio = "Gekomprimeerd"; break;
case "alle":  					$messaggio = "at"; break;
case "Non ho il permesso di scrittura sul file":	$messaggio = "I don't have write permissions on the file"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, before restoring the data from <i>file</i>, all data from <i>current database</i> will be <b>deleted</b>"; break;
case "Tipo di database":  			$messaggio = "Database type"; break;
case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
case "La versione attuale di hoteldruid e quella del file non coincidono":	$messaggio = "The current version of hoteldruid and the one of the file are not the same"; break;
case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "to save it (possibly use the browser back button to come back here)"; break;
case "Ho fatto l'upload del file":		$messaggio = "You have uploaded the file"; break;
case "Fai l'upload":  				$messaggio = "Upload"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
case "Backup dei documenti":  			$messaggio = "Documents backup"; break;
case "Crea il file di backup dei documenti":  	$messaggio = "Create documents backup file"; break;
case "Crea un nuovo file di backup dei documenti":	$messaggio = "Create a new documents backup file"; break;
case " del file di backup dei documenti":	$messaggio = " this documents backup file"; break;
case " di un nuovo file di backup dei documenti":	$messaggio = " this new documents backup file"; break;
case " l'attuale file di backup dei documenti":	$messaggio = " current documents backup file"; break;
case "aggiungi ai documenti attuali":  		$messaggio = "add to current documents"; break;
case "rimpiazza i documenti attuali":  		$messaggio = "replace current documents"; break;
case "i documenti attuali verranno cancellati":	$messaggio = "current documents will be deleted"; break;
case "Ripristina i documenti dal file":  	$messaggio = "Restore documents from file"; break;
case "Documenti ripristinati":  		$messaggio = "Documents restored"; break;
case "Backup completo":  			$messaggio = "Complete backup"; break;
case "Includi i modelli internet":  		$messaggio = "Include internet templates"; break;
case "creato il":  				$messaggio = "created"; break;
case "copia":  					$messaggio = "copy"; break;
case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
case "file copiato":  				$messaggio = "file copied"; break;
case "si è verificato un errore copiando il file":	$messaggio = "There was an error copying the file"; break;
case "Errori":  				$messaggio = "Errors"; break;
case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
case "solo il documento":  			$messaggio = "only document"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/crea_backup.php <==
<?php

switch ($messaggio) {

case "File creato":  				$messaggio = "File gemaakt"; break;
case "Si è verificato un errore cancellando il file":	$messaggio = "Er is een fout opgetreden met het wissen van de file"; break;
case "File cancellato":  			$messaggio = "File gewist"; break;
case "Inserisci i nuovi dati per la connessione al database":	$messaggio = "Voeg nieuwe data in voor verbinding met database"; break;
case "Nome del database da utilizzare":		$messaggio = "Te gebruiken database naam"; break;
case "Database già esistente":  		$messaggio = "Bestaande ddatabase"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nee"; break;
case "Se già esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "Indien reeds bestaand en niet leeg gebruik dan een prefix die niet in de database voor tabelnamen wordt gebruikt"; break;
case "Nome del computer a cui collegarsi":	$messaggio = "Naam van de computer waarmee verbonden moet worden"; break;
case "Numero della porta a cui collegarsi":	$messaggio = "Poortnaam waarmee verbonden moet worden"; break;
case "Nome per l'autenticazione al database":	$messaggio = "Gebruikersnaam voor databse verificatie"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Password voor database verificatie"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Laad de dynamische librarie \"pgsql.so\" of \"mysql.so\""; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "kies ja als er niet automatisch wordt geladen door PHP"; break;
case "Nome del database a cui collegarsi temporaneamente":	$messaggio = "Naam van de database waarmee tijdelijk wordt verbonden"; break;
case "solo per Postgresql con database non esistente":	$messaggio = "allen voor Postgresql met niet bestaande database"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "Vecchio database svuotato, per rimuoverlo del tutto procedere manualmente":	$messaggio = "Oude databse leeg gemaakt, en kan niet geheel worden verwijderd"; break;
case "Database creato":  			$messaggio = "Database gemaakt"; break;
case "Non è stato possibile connettersi al nuovo database, controllare i dati per la connessione, i privilegi dell' utente o il nome del database":	$messaggio = "Het was niet mogelijk om met de nieuwe database verbinding te maken, controleer verbindings gegevens, de gebruikers rechten of de naam van de database"; break;
case "Non è stato possibile creare il nuovo database, controllare i dati per la connessione, i privilegi dell' utente, il nome del database o se esiste già un database chiamato":	$messaggio = "Het was niet mogelijk een neiuwe databse te makencontroleer verbindings gegevens, de gebruikers rechten of de naam van de database of dat er een database reeds bestaat genaamd"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Ik heb geen schrijfrechten in de dati map"; break;
case "Non ho potuto leggere il file":  		$messaggio = "De file is niet leesbaar"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Crea il file di backup":  		$messaggio = "Maak een backup file"; break;
case "Crea un nuovo file di backup":  		$messaggio = "Maak een nieuwe backup file"; break;
case "sovrascrivendo l'attuale":  		$messaggio = "overschrijf de huidige"; break;
case "Guarda il file":				$messaggio = "Bekijk de file"; break;
case "Cancella":  				$messaggio = "Wis"; break;
case " l'attuale file di backup":  		$messaggio = " huidige backup file"; break;
case "Ripristina i dati dal file":  		$messaggio = "Herstel data van file"; break;
case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":	$messaggio = " (huidige data owrdt gewist), gebruiken voor maken van database:"; break;
case "i dati dell'attuale connessione":  	$messaggio = "data van huidige verbinding"; break;
case "nuovi dati":  				$messaggio = "nieuwe data"; break;
case "Non ho potuto fare l'upload del file":	$messaggio = "Niet mogelijk de file te uploaden"; break;
case " del file di backup":  			$messaggio = " deze backup file"; break;
case " di un nuovo file di backup":  		$messaggio = " deze nieuwe backup file"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix in tabellen naam"; break;
case "Il prefisso del nome delle tabelle è sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "De prefix van tabelnamen is verkeerd (accepteer alleen kleine letters, getallen en _ , als eerste letter)"; break;
case "Il contenuto del file inviato non è corretto":	$messaggio = "De inhoud van de verzedn file is verkeeerd"; break;
case "Il formato del file è errato":  		$messaggio = "Het file formaat is verkeerd"; break;
case "Compresso":  				$messaggio = "Gekomprimeerd"; break;
case "alle":  					$messaggio = "at"; break;
case "Backup":  				$messaggio = "Backup"; break;
case "Non ho il permesso di scrittura sul file":	$messaggio = "I don't have write permissions on the file"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, prima di ripristinare i dati dal <i>file</i>, tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, before restoring the data from <i>file</i>, all data from <i>current database</i> will be <b>deleted</b>"; break;
case "Tipo di database":  			$messaggio = "Database type"; break;
case "Normalmete 5432 o 5433 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 or 5433 for Postgresql or 3306 for Mysql"; break;
case "La versione attuale di HotelDruid e quella del file non coincidono":	$messaggio = "The current version of HotelDruid and the one of the file are not the same"; break;
case "La versione attuale e quella del file non coincidono":	$messaggio = "The current version and the one of the file are not the same"; break;
case "Sistema di backup per HotelDruid":  	$messaggio = "Backup system for HotelDruid"; break;
case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "to save it (possibly use the browser back button to come back here)"; break;
case "Ho fatto l'upload del file":		$messaggio = "You have uploaded the file"; break;
case "Fai l'upload":  				$messaggio = "Upload"; break;
case "opzionale, utile per più installazioni di hoteldruid nello stesso database":	$messaggio = "optional, useful for more installations of hoteldruid in the same database"; break;
case "Backup dei documenti":  			$messaggio = "Documents backup"; break;
case "Crea il file di backup dei documenti":  	$messaggio = "Create documents backup file"; break;
case "Crea un nuovo file di backup dei documenti":	$messaggio = "Create a new documents backup file"; break;
case " del file di backup dei documenti":	$messaggio = " this documents backup file"; break;
case " di un nuovo file di backup dei documenti":	$messaggio = " this new documents backup file"; break;
case " l'attuale file di backup dei documenti":	$messaggio = " current documents backup file"; break;
case "aggiungi ai documenti attuali":  		$messaggio = "add to current documents"; break;
case "rimpiazza i documenti attuali":  		$messaggio = "replace current documents"; break;
case "i documenti attuali verranno cancellati":	$messaggio = "current documents will be deleted"; break;
case "Ripristina i documenti dal file":  	$messaggio = "Restore documents from file"; break;
case "Documenti ripristinati":  		$messaggio = "Documents restored"; break;
case "Backup completo":  			$messaggio = "Complete backup"; break;
case "Includi le pagine per il sito web":  	$messaggio = "Include website pages"; break;
case "creato il":  				$messaggio = "created"; break;
case "copia":  					$messaggio = "copy"; break;
case "il file di backup dai documenti predefiniti in":	$messaggio = "the backup file from default documents in"; break;
case "file copiato":  				$messaggio = "file copied"; break;
case "si è verificato un errore copiando il file":	$messaggio = "There was an error copying the file"; break;
case "Errori":  				$messaggio = "Errors"; break;
case "Includi tutti gli anni":  		$messaggio = "Include all years"; break;
case "Includi solo gli anni selezionati":  	$messaggio = "Include only selected years"; break;
case "Prova a mantenere i dati degli anni non contenuti nel backup":	$messaggio = "Try to retain data of years not contained in the backup"; break;
case "alcuni dati di questi anni potrebbero comunque venir persi":	$messaggio = "some data of these years may be lost anyway"; break;
case "tutti i documenti contenuti nel file":	$messaggio = "all the documents contained in file"; break;
case "solo il documento":  			$messaggio = "only document"; break;
case "Raggiunto il limite giornaliero di backup":	$messaggio = "You have reached the limit of daily backups"; break;
case "Il file di backup contiene più di":  	$messaggio = "The backup file contains more than"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
